@@ -52,6 +52,7 @@
 #include "magick/color-private.h"
 #include "magick/colormap.h"
 #include "magick/colorspace.h"
+#include "magick/colorspace-private.h"
 #include "magick/constitute.h"
 #include "magick/exception.h"
 #include "magick/exception-private.h"
@@ -285,19 +286,16 @@ static MagickBooleanType JPEGErrorHandler(j_common_ptr jpeg_info)
   *message='\0';
   error_manager=(ErrorManager *) jpeg_info->client_data;
   image=error_manager->image;
+  (jpeg_info->err->format_message)(jpeg_info,message);
   if (image->debug != MagickFalse)
-    {
-      /*
-        Log trace message.
-      */
-      (jpeg_info->err->format_message)(jpeg_info,message);
-      (void) LogMagickEvent(CoderEvent,GetMagickModule(),
-        "[%s] JPEG Trace: \"%s\"",image->filename,message);
-    }
+    (void) LogMagickEvent(CoderEvent,GetMagickModule(),
+      "[%s] JPEG Trace: \"%s\"",image->filename,message);
   if (error_manager->finished != MagickFalse)
-    ThrowBinaryException(CorruptImageWarning,(char *) message,image->filename)
+    (void) ThrowMagickException(&image->exception,GetMagickModule(),
+      CorruptImageWarning,(char *) message,image->filename);
   else
-    ThrowBinaryException(CorruptImageError,(char *) message,image->filename);
+    (void) ThrowMagickException(&image->exception,GetMagickModule(),
+      CorruptImageError,(char *) message,image->filename);
   longjmp(error_manager->error_recovery,1);
 }
 
@@ -372,7 +370,7 @@ static boolean ReadComment(j_decompress_ptr jpeg_info)
   if (length <= 0)
     return(MagickTrue);
   comment=(char *) NULL;
-  if (~length >= MaxTextExtent)
+  if (~length >= (MaxTextExtent-1))
     comment=(char *) AcquireQuantumMemory(length+MaxTextExtent,
       sizeof(*comment));
   if (comment == (char *) NULL)
@@ -573,6 +571,9 @@ static boolean ReadProfile(j_decompress_ptr jpeg_info)
   char
     name[MaxTextExtent];
 
+  const StringInfo
+    *previous_profile;
+
   ErrorManager
     *error_manager;
 
@@ -614,7 +615,7 @@ static boolean ReadProfile(j_decompress_ptr jpeg_info)
     ThrowBinaryException(ResourceLimitError,"MemoryAllocationFailed",
       image->filename);
   p=GetStringInfoDatum(profile);
-  for (i=(ssize_t) GetStringInfoLength(profile)-1; i >= 0; i--)
+  for (i=0; i < (ssize_t) GetStringInfoLength(profile); i++)
     *p++=(unsigned char) GetCharacter(jpeg_info);
   if (marker == 1)
     {
@@ -641,6 +642,17 @@ static boolean ReadProfile(j_decompress_ptr jpeg_info)
           (void) CopyMagickString(name,"xmp",MaxTextExtent);
         }
     }
+  previous_profile=GetImageProfile(image,name);
+  if (previous_profile != (const StringInfo *) NULL)
+    {
+      SetStringInfoLength(profile,GetStringInfoLength(profile)+
+        GetStringInfoLength(previous_profile));
+      (void) memcpy(GetStringInfoDatum(profile),GetStringInfoDatum(profile)+
+        GetStringInfoLength(previous_profile),GetStringInfoLength(profile));
+      (void) memcpy(GetStringInfoDatum(profile),
+        GetStringInfoDatum(previous_profile),
+        GetStringInfoLength(previous_profile));
+    }
   status=SetImageProfile(image,name,profile);
   profile=DestroyStringInfo(profile);
   if (status == MagickFalse)
@@ -1248,10 +1260,8 @@ static Image *ReadJPEGImage(const ImageInfo *image_info,
             else
               pixel=(size_t) ((GETJSAMPLE(*p) ^ 0x80) << 4);
             index=ConstrainColormapIndex(image,pixel);
-            SetIndexPixelComponent(indexes+x,index);
-            SetRedPixelComponent(q,image->colormap[(int) index].red);
-            SetGreenPixelComponent(q,image->colormap[(int) index].green);
-            SetBluePixelComponent(q,image->colormap[(int) index].blue);
+            SetPixelIndex(indexes+x,index);
+            SetPixelRGBO(q,image->colormap+(ssize_t) index);
             p++;
             q++;
           }
@@ -1259,27 +1269,27 @@ static Image *ReadJPEGImage(const ImageInfo *image_info,
           if (image->colorspace != CMYKColorspace)
             for (x=0; x < (ssize_t) image->columns; x++)
             {
-              SetRedPixelComponent(q,ScaleShortToQuantum((unsigned char)
+              SetPixelRed(q,ScaleShortToQuantum((unsigned char)
                 (GETJSAMPLE(*p++) << 4)));
-              SetGreenPixelComponent(q,ScaleShortToQuantum((unsigned char)
+              SetPixelGreen(q,ScaleShortToQuantum((unsigned char)
                 (GETJSAMPLE(*p++) << 4)));
-              SetBluePixelComponent(q,ScaleShortToQuantum((unsigned char)
+              SetPixelBlue(q,ScaleShortToQuantum((unsigned char)
                 (GETJSAMPLE(*p++) << 4)));
-              SetOpacityPixelComponent(q,OpaqueOpacity);
+              SetPixelOpacity(q,OpaqueOpacity);
               q++;
             }
           else
             for (x=0; x < (ssize_t) image->columns; x++)
             {
-              SetCyanPixelComponent(q,QuantumRange-ScaleShortToQuantum(
+              SetPixelCyan(q,QuantumRange-ScaleShortToQuantum(
                 (unsigned char) (GETJSAMPLE(*p++) << 4)));
-              SetMagentaPixelComponent(q,QuantumRange-ScaleShortToQuantum(
+              SetPixelMagenta(q,QuantumRange-ScaleShortToQuantum(
                 (unsigned char) (GETJSAMPLE(*p++) << 4)));
-              SetYellowPixelComponent(q,QuantumRange-ScaleShortToQuantum(
+              SetPixelYellow(q,QuantumRange-ScaleShortToQuantum(
                 (unsigned char) (GETJSAMPLE(*p++) << 4)));
-              SetBlackPixelComponent(indexes+x,QuantumRange-ScaleShortToQuantum(
+              SetPixelBlack(indexes+x,QuantumRange-ScaleShortToQuantum(
                 (unsigned char) (GETJSAMPLE(*p++) << 4)));
-              SetOpacityPixelComponent(q,OpaqueOpacity);
+              SetPixelOpacity(q,OpaqueOpacity);
               q++;
             }
       }
@@ -1288,10 +1298,8 @@ static Image *ReadJPEGImage(const ImageInfo *image_info,
         for (x=0; x < (ssize_t) image->columns; x++)
         {
           index=ConstrainColormapIndex(image,(size_t) GETJSAMPLE(*p));
-          SetIndexPixelComponent(indexes+x,index);
-          SetRedPixelComponent(q,image->colormap[(int) index].red);
-          SetGreenPixelComponent(q,image->colormap[(int) index].green);
-          SetBluePixelComponent(q,image->colormap[(int) index].blue);
+          SetPixelIndex(indexes+x,index);
+          SetPixelRGBO(q,image->colormap+(ssize_t) index);
           p++;
           q++;
         }
@@ -1299,27 +1307,27 @@ static Image *ReadJPEGImage(const ImageInfo *image_info,
         if (image->colorspace != CMYKColorspace)
           for (x=0; x < (ssize_t) image->columns; x++)
           {
-            SetRedPixelComponent(q,ScaleCharToQuantum((unsigned char)
+            SetPixelRed(q,ScaleCharToQuantum((unsigned char)
               GETJSAMPLE(*p++)));
-            SetGreenPixelComponent(q,ScaleCharToQuantum((unsigned char)
+            SetPixelGreen(q,ScaleCharToQuantum((unsigned char)
               GETJSAMPLE(*p++)));
-            SetBluePixelComponent(q,ScaleCharToQuantum((unsigned char)
+            SetPixelBlue(q,ScaleCharToQuantum((unsigned char)
               GETJSAMPLE(*p++)));
-            SetOpacityPixelComponent(q,OpaqueOpacity);
+            SetPixelOpacity(q,OpaqueOpacity);
             q++;
           }
         else
           for (x=0; x < (ssize_t) image->columns; x++)
           {
-            SetCyanPixelComponent(q,QuantumRange-ScaleCharToQuantum(
+            SetPixelCyan(q,QuantumRange-ScaleCharToQuantum(
               (unsigned char) GETJSAMPLE(*p++)));
-            SetMagentaPixelComponent(q,QuantumRange-ScaleCharToQuantum(
+            SetPixelMagenta(q,QuantumRange-ScaleCharToQuantum(
               (unsigned char) GETJSAMPLE(*p++)));
-            SetYellowPixelComponent(q,QuantumRange-ScaleCharToQuantum(
+            SetPixelYellow(q,QuantumRange-ScaleCharToQuantum(
               (unsigned char) GETJSAMPLE(*p++)));
-            SetBlackPixelComponent(indexes+x,QuantumRange-ScaleCharToQuantum(
+            SetPixelBlack(indexes+x,QuantumRange-ScaleCharToQuantum(
               (unsigned char) GETJSAMPLE(*p++)));
-            SetOpacityPixelComponent(q,OpaqueOpacity);
+            SetPixelOpacity(q,OpaqueOpacity);
             q++;
           }
     if (SyncAuthenticPixels(image,exception) == MagickFalse)
@@ -1815,7 +1823,7 @@ static MagickBooleanType WriteJPEGImage(const ImageInfo *image_info,
     }
     default:
     {
-      if (image->colorspace != RGBColorspace)
+      if (IsRGBColorspace(image->colorspace) == MagickFalse)
         (void) TransformImageColorspace(image,RGBColorspace);
       break;
     }
@@ -2232,9 +2240,9 @@ static MagickBooleanType WriteJPEGImage(const ImageInfo *image_info,
           q=jpeg_pixels;
           for (x=0; x < (ssize_t) image->columns; x++)
           {
-            *q++=(JSAMPLE) ScaleQuantumToChar(GetRedPixelComponent(p));
-            *q++=(JSAMPLE) ScaleQuantumToChar(GetGreenPixelComponent(p));
-            *q++=(JSAMPLE) ScaleQuantumToChar(GetBluePixelComponent(p));
+            *q++=(JSAMPLE) ScaleQuantumToChar(GetPixelRed(p));
+            *q++=(JSAMPLE) ScaleQuantumToChar(GetPixelGreen(p));
+            *q++=(JSAMPLE) ScaleQuantumToChar(GetPixelBlue(p));
             p++;
           }
           (void) jpeg_write_scanlines(&jpeg_info,scanline,1);
@@ -2291,13 +2299,13 @@ static MagickBooleanType WriteJPEGImage(const ImageInfo *image_info,
                 Convert DirectClass packets to contiguous CMYK scanlines.
               */
               *q++=(JSAMPLE) (ScaleQuantumToChar((Quantum) (QuantumRange-
-                GetRedPixelComponent(p))));
+                GetPixelRed(p))));
               *q++=(JSAMPLE) (ScaleQuantumToChar((Quantum) (QuantumRange-
-                GetGreenPixelComponent(p))));
+                GetPixelGreen(p))));
               *q++=(JSAMPLE) (ScaleQuantumToChar((Quantum) (QuantumRange-
-                GetBluePixelComponent(p))));
+                GetPixelBlue(p))));
               *q++=(JSAMPLE) (ScaleQuantumToChar((Quantum) (QuantumRange-
-                GetIndexPixelComponent(indexes+x))));
+                GetPixelIndex(indexes+x))));
               p++;
             }
             (void) jpeg_write_scanlines(&jpeg_info,scanline,1);
@@ -2350,11 +2358,11 @@ static MagickBooleanType WriteJPEGImage(const ImageInfo *image_info,
           q=jpeg_pixels;
           for (x=0; x < (ssize_t) image->columns; x++)
           {
-            *q++=(JSAMPLE) (ScaleQuantumToShort(GetRedPixelComponent(p)) >>
+            *q++=(JSAMPLE) (ScaleQuantumToShort(GetPixelRed(p)) >>
               4);
-            *q++=(JSAMPLE) (ScaleQuantumToShort(GetGreenPixelComponent(p)) >>
+            *q++=(JSAMPLE) (ScaleQuantumToShort(GetPixelGreen(p)) >>
               4);
-            *q++=(JSAMPLE) (ScaleQuantumToShort(GetBluePixelComponent(p)) >>
+            *q++=(JSAMPLE) (ScaleQuantumToShort(GetPixelBlue(p)) >>
               4);
             p++;
           }
@@ -2387,13 +2395,13 @@ static MagickBooleanType WriteJPEGImage(const ImageInfo *image_info,
               Convert DirectClass packets to contiguous CMYK scanlines.
             */
             *q++=(JSAMPLE) (4095-(ScaleQuantumToShort(
-              GetRedPixelComponent(p)) >> 4));
+              GetPixelRed(p)) >> 4));
             *q++=(JSAMPLE) (4095-(ScaleQuantumToShort(
-              GetGreenPixelComponent(p)) >> 4));
+              GetPixelGreen(p)) >> 4));
             *q++=(JSAMPLE) (4095-(ScaleQuantumToShort(
-              GetBluePixelComponent(p)) >> 4));
+              GetPixelBlue(p)) >> 4));
             *q++=(JSAMPLE) (4095-(ScaleQuantumToShort(
-              GetIndexPixelComponent(indexes+x)) >> 4));
+              GetPixelIndex(indexes+x)) >> 4));
             p++;
           }
           (void) jpeg_write_scanlines(&jpeg_info,scanline,1);
