@@ -168,7 +168,7 @@ MagickExport StringInfo *AcquireStringInfo(const size_t length)
   if (string_info->length != 0)
     {
       string_info->datum=(unsigned char *) NULL;
-      if (~string_info->length >= MaxTextExtent)
+      if (~string_info->length >= (MaxTextExtent-1))
         string_info->datum=(unsigned char *) AcquireQuantumMemory(
           string_info->length+MaxTextExtent,sizeof(*string_info->datum));
       if (string_info->datum == (unsigned char *) NULL)
@@ -551,7 +551,7 @@ MagickExport StringInfo *ConfigureFileToStringInfo(const char *filename)
     }
   length=(size_t) offset;
   string=(char *) NULL;
-  if (~length > MaxTextExtent)
+  if (~length >= (MaxTextExtent-1))
     string=(char *) AcquireQuantumMemory(length+MaxTextExtent,sizeof(*string));
   if (string == (char *) NULL)
     {
@@ -873,7 +873,7 @@ MagickExport char *EscapeString(const char *source,const char escape)
         length++;
       }
   destination=(char *) NULL;
-  if (~length >= MaxTextExtent)
+  if (~length >= (MaxTextExtent-1))
     destination=(char *) AcquireQuantumMemory(length+MaxTextExtent,
       sizeof(*destination));
   if (destination == (char *) NULL)
@@ -1757,7 +1757,7 @@ MagickExport StringInfo *SplitStringInfo(StringInfo *string_info,
     return((StringInfo *) NULL);
   split_info=AcquireStringInfo(offset);
   SetStringInfo(split_info,string_info);
-  (void) memcpy(string_info->datum,string_info->datum+offset,
+  (void) memmove(string_info->datum,string_info->datum+offset,
     string_info->length-offset+MaxTextExtent);
   SetStringInfoLength(string_info,string_info->length-offset);
   return(split_info);
@@ -1795,7 +1795,7 @@ MagickExport char *StringInfoToString(const StringInfo *string_info)
 
   string=(char *) NULL;
   length=string_info->length;
-  if (~length >= MaxTextExtent)
+  if (~length >= (MaxTextExtent-1))
     string=(char *) AcquireQuantumMemory(length+MaxTextExtent,sizeof(*string));
   if (string == (char *) NULL)
     return((char *) NULL);
@@ -2199,7 +2199,7 @@ MagickExport char **StringToList(const char *text)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  StringToStringInfo() returns the contents of a file as a string.
+%  StringToStringInfo() converts a string to a StringInfo type.
 %
 %  The format of the StringToStringInfo method is:
 %
@@ -2217,7 +2217,7 @@ MagickExport StringInfo *StringToStringInfo(const char *string)
 
   (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
   assert(string != (const char *) NULL);
-  string_info=AcquireStringInfo(strlen(string)+1);
+  string_info=AcquireStringInfo(strlen(string));
   SetStringInfoDatum(string_info,(const unsigned char *) string);
   return(string_info);
 }
@@ -2269,7 +2269,7 @@ MagickExport void StripString(char *message)
   if (q > p)
     if ((*q == '\'') || (*q == '"'))
       q--;
-  (void) memcpy(message,p,(size_t) (q-p+1));
+  (void) memmove(message,p,(size_t) (q-p+1));
   message[q-p+1]='\0';
   for (p=message; *p != '\0'; p++)
     if (*p == '\n')
