@@ -1298,35 +1298,6 @@ MagickExport void GetPathComponent(const char *path,PathType type,
     }
   (void) CopyMagickString(component,path,MaxTextExtent);
   *magick='\0';
-#if defined(__OS2__)
-  if (path[1] != ":")
-#endif
-  for (p=component; *p != '\0'; p++)
-  {
-    if ((*p == '%') && (*(p+1) == '['))
-      {
-        /*
-          Skip over %[...].
-        */
-        for (p++; (*p != ']') && (*p != '\0'); p++) ;
-        if (*p == '\0')
-          break;
-      }
-    if ((*p == ':') && (IsPathDirectory(path) < 0) &&
-        (IsPathAccessible(path) == MagickFalse))
-      {
-        /*
-          Look for image format specification (e.g. ps3:image).
-        */
-        (void) CopyMagickString(magick,component,(size_t) (p-component+1));
-        if (IsMagickConflict(magick) != MagickFalse)
-          *magick='\0';
-        else
-          for (q=component; *q != '\0'; q++)
-            *q=(*++p);
-        break;
-      }
-  }
   *subimage='\0';
   p=component;
   if (*p != '\0')
@@ -1351,6 +1322,35 @@ MagickExport void GetPathComponent(const char *path,PathType type,
             *q='\0';
         }
     }
+#if defined(__OS2__)
+  if (path[1] != ':')
+#endif
+  for (p=component; *p != '\0'; p++)
+  {
+    if ((*p == '%') && (*(p+1) == '['))
+      {
+        /*
+          Skip over %[...].
+        */
+        for (p++; (*p != ']') && (*p != '\0'); p++) ;
+        if (*p == '\0')
+          break;
+      }
+    if ((*p == ':') && (IsPathDirectory(component) < 0) &&
+        (IsPathAccessible(component) == MagickFalse))
+      {
+        /*
+          Look for image format specification (e.g. ps3:image).
+        */
+        (void) CopyMagickString(magick,component,(size_t) (p-component+1));
+        if (IsMagickConflict(magick) != MagickFalse)
+          *magick='\0';
+        else
+          for (q=component; *q != '\0'; q++)
+            *q=(*++p);
+        break;
+      }
+  }
   p=component;
   if (*p != '\0')
     for (p=component+strlen(component)-1; p > component; p--)
