@@ -46,12 +46,12 @@ extern "C" {
 #if defined(_magickcore_inline) && !defined(inline)
 # define inline _magickcore_inline
 #endif
-# if defined(__cplusplus) || defined(c_plusplus)
-#  undef inline
-# endif
 #if defined(_magickcore_restrict) && !defined(restrict)
 # define restrict  _magickcore_restrict
 #endif
+# if defined(__cplusplus) || defined(c_plusplus)
+#  undef inline
+# endif
 #endif
 
 #if !defined(const)
@@ -190,6 +190,9 @@ extern "C" {
 #include <signal.h>
 #include <assert.h>
 
+#if defined(MAGICKCORE_HAVE_XLOCALE_H)
+# include <xlocale.h>
+#endif
 #if defined(MAGICKCORE_THREAD_SUPPORT)
 # include <pthread.h>
 #elif defined(MAGICKCORE_WINDOWS_SUPPORT)
@@ -429,16 +432,8 @@ extern int vsnprintf(char *,size_t,const char *,va_list);
 #endif
 
 /*
-  I/O defines.
+  Exception defines.
 */
-#if defined(MAGICKCORE_WINDOWS_SUPPORT) && !defined(Windows95) && !defined(__BORLANDC__)
-#define MagickSeek(file,offset,whence)  _lseeki64(file,offset,whence)
-#define MagickTell(file)  _telli64(file)
-#else
-#define MagickSeek(file,offset,whence)  lseek(file,offset,whence)
-#define MagickTell(file) tell(file)
-#endif
-
 #define ThrowWandFatalException(severity,tag,context) \
 { \
   ExceptionInfo \
